@@ -25,6 +25,7 @@
 #include <glib.h>
 #include <json-glib/json-glib.h>
 #include "config.h"
+#include "couchdb-document.h"
 #include "couchdb-session.h"
 
 #ifndef DEBUG_MESSAGES
@@ -37,8 +38,21 @@ GQuark      couchdb_error_quark (void);
 
 char* generate_uuid (void);
 
+GType get_type_from_field (JsonObject *object, const char *field);
+
+gchar *couchdb_uri_encode (const gchar *uri);
+
 /* Private API */
-JsonObject*	  couchdb_document_get_json_object	(CouchdbDocument *document);
+gboolean            couchdb_session_send_message (CouchdbSession *session,
+						  const char *method,
+						  const char *url,
+						  const char *body,
+						  JsonParser *output,
+						  GError **error);
+
+CouchdbDocument    *couchdb_document_new_from_json_object (JsonObject *json_object);
+void                couchdb_document_set_from_json_object (CouchdbDocument *document, JsonObject *json_object);
+JsonObject*	    couchdb_document_get_json_object	(CouchdbDocument *document);
 
 CouchdbArrayField  *couchdb_array_field_new_from_json_array (JsonArray *json_array);
 JsonArray          *couchdb_array_field_get_json_array (CouchdbArrayField *array);
